# libpythonpro

Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://travis-ci.com/ggoldani/libpythonpro.svg?branch=master)](https://travis-ci.com/ggoldani/libpythonpro)
[![codecov](https://codecov.io/gh/ggoldani/libpythonpro/branch/master/graph/badge.svg?token=EECPMJ5X83)](https://codecov.io/gh/ggoldani/libpythonpro)

Suportada versão 3 de Python

Instalação:
```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Conferencia de qualidade do código:
```console
flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip
 